AbiType

Enum AbiType 

pub enum AbiType {
Show 17 variants Uint(u16), Int(u16), VarUint(NonZeroU8), VarInt(NonZeroU8), Bool, Cell, Address, Bytes, FixedBytes(usize), String, Token, Tuple(Arc<[NamedAbiType]>), Array(Arc<Self>), FixedArray(Arc<Self>, usize), Map(PlainAbiType, Arc<Self>), Optional(Arc<Self>), Ref(Arc<Self>),
}
ABI value type.

Variants



Uint(u16)

Unsigned integer of n bits.



Int(u16)

Signed integer of n bits.



VarUint(NonZeroU8)

Variable-length unsigned integer of maximum n bytes.



VarInt(NonZeroU8)

Variable-length signed integer of maximum n bytes.



Bool

Boolean.



Cell

Tree of cells (Cell).



Address

Internal address (IntAddr).



Bytes

Byte array.



FixedBytes(usize)

Byte array of fixed length.



String

Utf8-encoded string.



Token

Variable length 120-bit integer (Tokens).



Tuple(Arc<[NamedAbiType]>)

Product type.



Array(Arc<Self>)

Array of elements of the specified ABI type.



FixedArray(Arc<Self>, usize)

Fixed-length array of elements of the specified ABI type.



Map(PlainAbiType, Arc<Self>)

Dictionary with the specified key and value ABI types.



Optional(Arc<Self>)

Optional type.



Ref(Arc<Self>)

Type stored in a new cell.

Implementations

Source

impl AbiType

pub fn named<T: Into<String>>(self, name: T) -> NamedAbiType

Returns a named ABI type.

pub fn as_plain(&self) -> Option<PlainAbiType>

Tries to convert a generic ABI type into a plain ABI type.

pub fn max_size(&self) -> CellTreeStats

Returns the maximum number of bits and refs that this type can occupy.

pub fn max_bits(&self) -> usize

Returns the maximum number of bits that this type can occupy.

pub fn max_refs(&self) -> usize

Returns the maximum number of cells that this type can occupy.

pub fn flatten(self) -> AbiTypeFlatten

Returns an iterator with the first-level tuple flattened.

Can be used to pass an ABI struct as arguments to the FunctionBuilder::with_unnamed_inputs or FunctionBuilder::with_unnamed_outputs

pub fn varuint(size: u8) -> Self

Simple varuintN type constructor.

pub fn varint(size: u8) -> Self

Simple varintN type constructor.

pub fn tuple<I, T>(values: I) -> Self
where I: IntoIterator<Item = T>, NamedAbiType: From<T>,

Simple tuple type constructor.

pub fn unnamed_tuple<I>(values: I) -> Self
where I: IntoIterator<Item = AbiType>,

Simple tuple type constructor.

pub fn array<T>(ty: T) -> Self
where Arc<AbiType>: From<T>,

Simple array type constructor.

pub fn fixedarray<T>(ty: T, len: usize) -> Self
where Arc<AbiType>: From<T>,

Simple fixedarrayN type constructor.

pub fn map<V>(key_ty: PlainAbiType, value_ty: V) -> Self
where Arc<AbiType>: From<V>,

Simple tuple type constructor.

pub fn optional<T>(ty: T) -> Self
where Arc<AbiType>: From<T>,

Simple optional type constructor.

pub fn reference<T>(ty: T) -> Self
where Arc<AbiType>: From<T>,

Simple ref type constructor.

Source

impl AbiType

pub fn make_default_value(&self) -> AbiValue

Returns a default value corresponding to the this type.