AbiValue

Enum AbiValue 

pub enum AbiValue {
Show 17 variants Uint(u16, BigUint), Int(u16, BigInt), VarUint(NonZeroU8, BigUint), VarInt(NonZeroU8, BigInt), Bool(bool), Cell(Cell), Address(Box<IntAddr>), Bytes(Bytes), FixedBytes(Bytes), String(String), Token(Tokens), Tuple(Vec<NamedAbiValue>), Array(Arc<AbiType>, Vec<Self>), FixedArray(Arc<AbiType>, Vec<Self>), Map(PlainAbiType, Arc<AbiType>, BTreeMap<PlainAbiValue, AbiValue>), Optional(Arc<AbiType>, Option<Box<Self>>), Ref(Box<Self>),
}
ABI encoded value.

Variants



Uint(u16, BigUint)

Unsigned integer of n bits.



Int(u16, BigInt)

Signed integer of n bits.



VarUint(NonZeroU8, BigUint)

Variable-length unsigned integer of maximum n bytes.



VarInt(NonZeroU8, BigInt)

Variable-length signed integer of maximum n bytes.



Bool(bool)

Boolean.



Cell(Cell)

Tree of cells (Cell).



Address(Box<IntAddr>)

Internal address (IntAddr).



Bytes(Bytes)

Byte array.



FixedBytes(Bytes)

Byte array of fixed length.



String(String)

Utf8-encoded string.



Token(Tokens)

Variable length 120-bit integer (Tokens).



Tuple(Vec<NamedAbiValue>)

Product type.



Array(Arc<AbiType>, Vec<Self>)

Array of ABI values.



FixedArray(Arc<AbiType>, Vec<Self>)

Fixed-length array of ABI values.



Map(PlainAbiType, Arc<AbiType>, BTreeMap<PlainAbiValue, AbiValue>)

Sorted dictionary of ABI values.



Optional(Arc<AbiType>, Option<Box<Self>>)

Optional value.



Ref(Box<Self>)

Value stored in a new cell.

Implementations

Source

impl AbiValue

pub fn check_remaining( slice: &mut CellSlice<'_>, allow_partial: bool, ) -> Result<()>

Checks whether the slice is empty and raises an error if we didn’t expect it to be empty.

pub fn load_tuple( types: &[AbiType], version: AbiVersion, slice: &mut CellSlice<'_>, ) -> Result<Vec<Self>>

Loads exactly one unnamed tuple from the specified slice requiring it to be fully consumed.

Use AbiValue::load_tuple_partial if you allow an ABI type to be a prefix.

pub fn load_tuple_partial( types: &[AbiType], version: AbiVersion, slice: &mut CellSlice<'_>, ) -> Result<Vec<Self>>

Loads an unnamed tuple from the specified slice.

pub fn load_tuple_ext( types: &[AbiType], version: AbiVersion, last: bool, allow_partial: bool, slice: &mut CellSlice<'_>, ) -> Result<Vec<Self>>

Loads an unnamed tuple from the specified slice with explicit decoder params.

NOTE: this method does not check the remaining bits and refs in the root slice.

pub fn load( ty: &AbiType, version: AbiVersion, slice: &mut CellSlice<'_>, ) -> Result<Self>

Loads exactly one ABI value from the specified slice requiring it to be fully consumed.

Use AbiValue::load_partial if you allow an ABI type to be a prefix.

pub fn load_partial( ty: &AbiType, version: AbiVersion, slice: &mut CellSlice<'_>, ) -> Result<Self>

Loads an ABI value from the specified slice.

pub fn load_ext( ty: &AbiType, version: AbiVersion, last: bool, allow_partial: bool, slice: &mut CellSlice<'_>, ) -> Result<Self>

Loads an ABI value from the specified slice with explicit decoder params.

NOTE: this method does not check the remaining bits and refs in the root slice.

Source

impl AbiValue

pub fn tuple_to_builder( values: &[Self], version: AbiVersion, ) -> Result<CellBuilder, Error>

Tries to store multiple values into a new builder according to the specified ABI version.

pub fn tuple_to_cell( values: &[Self], version: AbiVersion, ) -> Result<Cell, Error>

Builds a new cell from multiple values according to the specified ABI version.

pub fn make_builder(&self, version: AbiVersion) -> Result<CellBuilder, Error>

Tries to store this value into a new builder according to the specified ABI version.

pub fn make_cell(&self, version: AbiVersion) -> Result<Cell, Error>

Builds a new cell from this value according to the specified ABI version.

Source

impl AbiValue

pub fn named<T: Into<String>>(self, name: T) -> NamedAbiValue

Returns a named ABI value.

pub fn check_type<T: AsRef<AbiType>>(&self, ty: T) -> Result<()>

Ensures that value satisfies the type.

pub fn has_type(&self, ty: &AbiType) -> bool

Returns whether this value has the same type as the provided one.

pub fn get_type(&self) -> AbiType

Returns an ABI type of the value.

pub fn display_type(&self) -> impl Display + '_

Returns a printable object which will display a value type signature.

pub fn uint<T>(bits: u16, value: T) -> Self
where BigUint: From<T>,

Simple uintN constructor.

pub fn int<T>(bits: u16, value: T) -> Self
where BigInt: From<T>,

Simple intN constructor.

pub fn varuint<T>(size: u8, value: T) -> Self
where BigUint: From<T>,

Simple varuintN constructor.

pub fn varint<T>(size: u8, value: T) -> Self
where BigInt: From<T>,

Simple varintN constructor.

pub fn address<T>(value: T) -> Self
where IntAddr: From<T>,

Simple address constructor.

pub fn bytes<T>(value: T) -> Self
where Bytes: From<T>,

Simple bytes constructor.

pub fn fixedbytes<T>(value: T) -> Self
where Bytes: From<T>,

Simple bytes constructor.

pub fn tuple<I, T>(values: I) -> Self
where I: IntoIterator<Item = T>, NamedAbiValue: From<T>,

Simple tuple constructor.

pub fn unnamed_tuple<I>(values: I) -> Self
where I: IntoIterator<Item = AbiValue>,

Simple tuple constructor.

pub fn array<T, I>(values: I) -> Self
where T: WithAbiType + IntoAbi, I: IntoIterator<Item = T>,

Simple array constructor.

pub fn fixedarray<T, I>(values: I) -> Self
where T: WithAbiType + IntoAbi, I: IntoIterator<Item = T>,

Simple fixedarray constructor.

pub fn map<K, V, I>(entries: I) -> Self

Simple map constructor.

pub fn optional<T>(value: Option<T>) -> Self
where T: WithAbiType + IntoAbi,

Simple optional constructor.

pub fn reference<T>(value: T) -> Self
where T: IntoAbi,

Simple optional constructor.