pub enum PlainAbiType {
Uint(u16),
Int(u16),
Bool,
Address,
}Expand description
ABI type which has a fixed bits representation and therefore can be used as a map key.
Variants
Uint(u16)
Unsigned integer of n bits.
Int(u16)
Signed integer of n bits.
Bool
Boolean.
Address
Internal address (IntAddr).
Implementations