pub trait ExactSize {
// Required method
fn exact_size(&self) -> Size;
}Expand description
A type with a known size in bits and refs.
Required Methods
Sourcefn exact_size(&self) -> Size
fn exact_size(&self) -> Size
Exact size of the value when it is stored in a slice.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".