Branch

Enum Branch 

pub enum Branch {
    Left = 0,
    Right = 1,
}
Which branch to take when traversing the tree.

Variants



Left = 0

Branch for a key part that starts with bit 0



Right = 1

Branch for a key part that starts with bit 1

Implementations

Source

impl Branch

pub fn into_bit(self) -> bool

Converts the branch to a boolean value.

pub fn reversed(self) -> Self

Returns the opposite branch.