pub struct SpecialFlags {
pub tick: bool,
pub tock: bool,
}Expand description
Special transactions execution flags.
Fields
tick: boolAccount will be called at the beginning of each block.
tock: boolAccount will be called at the end of each block.
Implementations